@@ -16,6 +16,8 @@ class MspFrontend(object):
         return 'msp'
 
     def login(self, request, *args, **kwargs):
+        if 'nomsp' in request.GET:
+            return
         context_instance = kwargs.pop('context_instance', None)
         return render(request, 'authentic2_auth_msp/login.html',
                 context_instance=context_instance)
